@@ -4,6 +4,7 @@ import re
 import shutil
 import time
 import traceback
+from io import StringIO
 from math import floor
 from threading import Thread
 from typing import Iterable, List
@@ -12,7 +13,7 @@ from bauh.api.abstract.download import FileDownloader
 from bauh.api.abstract.handler import ProcessWatcher
 from bauh.api.http import HttpClient
 from bauh.commons.html import bold
-from bauh.commons.system import run_cmd, ProcessHandler, SimpleProcess, get_human_size_str
+from bauh.commons.system import ProcessHandler, SimpleProcess, get_human_size_str
 from bauh.view.util.translation import I18n
 
 RE_HAS_EXTENSION = re.compile(r'.+\.\w+$')
@@ -73,7 +74,7 @@ class AdaptableFileDownloader(FileDownloader):
         cmd = ['axel', url, '-n', str(threads), '-4', '-c', '-T', '5']
 
         if output_path:
-            cmd.append('--output={}'.format(output_path))
+            cmd.append(f'--output={output_path}')
 
         return SimpleProcess(cmd=cmd, cwd=cwd, root_password=root_password)
 
@@ -87,19 +88,22 @@ class AdaptableFileDownloader(FileDownloader):
         return SimpleProcess(cmd=cmd, cwd=cwd, root_password=root_password)
 
     def _rm_bad_file(self, file_name: str, output_path: str, cwd, handler: ProcessHandler, root_password: str):
-        to_delete = output_path if output_path else '{}/{}'.format(cwd, file_name)
+        to_delete = output_path if output_path else f'{cwd}/{file_name}'
 
         if to_delete and os.path.exists(to_delete):
-            self.logger.info('Removing downloaded file {}'.format(to_delete))
-            success, _ = handler.handle_simple(SimpleProcess(['rm', '-rf',to_delete], root_password=root_password))
+            self.logger.info(f'Removing downloaded file {to_delete}')
+            success, _ = handler.handle_simple(SimpleProcess(['rm', '-rf', to_delete], root_password=root_password))
             return success
 
-    def _display_file_size(self, file_url: str, base_substatus, watcher: ProcessWatcher):
+    def _concat_file_size(self, file_url: str, base_substatus: StringIO, watcher: ProcessWatcher):
+        watcher.change_substatus(f'{base_substatus.getvalue()} ( ? Mb )')
+
         try:
             size = self.http_client.get_content_length(file_url)
 
             if size:
-                watcher.change_substatus(base_substatus + ' ( {} )'.format(size))
+                base_substatus.write(f' ( {size} )')
+                watcher.change_substatus(base_substatus.getvalue())
         except:
             pass
 
@@ -117,7 +121,7 @@ class AdaptableFileDownloader(FileDownloader):
         return threads
 
     def download(self, file_url: str, watcher: ProcessWatcher, output_path: str = None, cwd: str = None, root_password: str = None, substatus_prefix: str = None, display_file_size: bool = True, max_threads: int = None, known_size: int = None) -> bool:
-        self.logger.info('Downloading {}'.format(file_url))
+        self.logger.info(f'Downloading {file_url}')
         handler = ProcessHandler(watcher)
         file_name = file_url.split('/')[-1]
 
@@ -127,9 +131,9 @@ class AdaptableFileDownloader(FileDownloader):
         ti = time.time()
         try:
             if output_path and os.path.exists(output_path):
-                self.logger.info('Removing old file found before downloading: {}'.format(output_path))
+                self.logger.info(f'Removing old file found before downloading: {output_path}')
                 os.remove(output_path)
-                self.logger.info("Old file {} removed".format(output_path))
+                self.logger.info(f'Old file {output_path} removed')
 
             client = self.get_available_multithreaded_tool()
             if client:
@@ -153,21 +157,20 @@ class AdaptableFileDownloader(FileDownloader):
             if output_path and not RE_HAS_EXTENSION.match(name) and RE_HAS_EXTENSION.match(output_path):
                 name = output_path.split('/')[-1]
 
-            if substatus_prefix:
-                msg = substatus_prefix + ' '
-            else:
-                msg = ''
-
-            msg += bold('[{}] ').format(downloader) + self.i18n['downloading'] + ' ' + bold(name)
-
             if watcher:
-                watcher.change_substatus(msg)
+                msg = StringIO()
+                msg.write(f'{substatus_prefix} ' if substatus_prefix else '')
+                msg.write(f"{bold('[{}]'.format(downloader))} {self.i18n['downloading']} {bold(name)}")
 
                 if display_file_size:
                     if known_size:
-                        watcher.change_substatus(msg + ' ( {} )'.format(get_human_size_str(known_size)))
+                        msg.write(f' ( {get_human_size_str(known_size)} )')
+                        watcher.change_substatus(msg.getvalue())
                     else:
-                        Thread(target=self._display_file_size, args=(file_url, msg, watcher)).start()
+                        Thread(target=self._concat_file_size, args=(file_url, msg, watcher)).start()
+                else:
+                    msg.write(' ( ? Mb )')
+                    watcher.change_substatus(msg.getvalue())
 
             success, _ = handler.handle_simple(process)
         except:
@@ -175,10 +178,10 @@ class AdaptableFileDownloader(FileDownloader):
             self._rm_bad_file(file_name, output_path, final_cwd, handler, root_password)
 
         tf = time.time()
-        self.logger.info(file_name + ' download took {0:.2f} minutes'.format((tf - ti) / 60))
+        self.logger.info(f'{file_name} download took {(tf - ti) / 60:.2f} minutes')
 
         if not success:
-            self.logger.error("Could not download '{}'".format(file_name))
+            self.logger.error(f"Could not download '{file_name}'")
             self._rm_bad_file(file_name, output_path, final_cwd, handler, root_password)
 
         return success
