@@ -13,6 +13,7 @@ from bauh import __app_name__
 from bauh.api.abstract.context import ApplicationContext
 from bauh.api.abstract.controller import SoftwareManager, SoftwareAction
 from bauh.api.abstract.handler import TaskManager
+from bauh.commons import user
 from bauh.view.qt.components import new_spacer, QCustomToolbar
 from bauh.view.qt.qt_utils import centralize
 from bauh.view.qt.root import RootDialog
@@ -55,7 +56,7 @@ class Prepare(QThread, TaskManager):
 
     def run(self):
         root_pwd = None
-        if self.manager.requires_root(SoftwareAction.PREPARE, None):
+        if not user.is_root() and self.manager.requires_root(SoftwareAction.PREPARE, None):
             ok, root_pwd = self.ask_password()
 
             if not ok:
@@ -152,9 +153,9 @@ class PreparePanel(QWidget, TaskManager):
         self.app_config = app_config
         self.manage_window = manage_window
         self.setWindowTitle('{} ({})'.format(__app_name__, self.i18n['prepare_panel.title.start'].lower()))
-        self.setMinimumWidth(screen_size.width() * 0.5)
-        self.setMinimumHeight(screen_size.height() * 0.35)
-        self.setMaximumHeight(screen_size.height() * 0.95)
+        self.setMinimumWidth(int(screen_size.width() * 0.5))
+        self.setMinimumHeight(int(screen_size.height() * 0.35))
+        self.setMaximumHeight(int(screen_size.height() * 0.95))
         self.setLayout(QVBoxLayout())
         self.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Preferred)
         self.manager = manager
